
###This R script replicates the models from Table A10 from the Online Appendix
### Load packages
require(foreign)
require(sandwich)
require(lmtest)
require(MASS)
require(Hmisc)
require(stargazer)
require(sciplot)
require(lme4)

### Clear space
rm(list = ls())

### Load function to incorporate uncertainty (with robust standard errors)
milm <- function(fml, midata){
  xx <- terms(as.formula(fml))
  lms <- matrix(data=NA, nrow=(length(attr(xx, "term.labels")) + 1), ncol=length(midata))
  ses <- matrix(data=NA, nrow=(length(attr(xx, "term.labels")) + 1), ncol=length(midata))
  vcovs <- list()
  for(i in 1:length(midata)){
    tmp <- lm(formula=as.formula(fml), data=midata[[i]])
    lms[,i] <- tmp$coefficients
    ses[,i] <- sqrt(diag(vcovHC(tmp, type = "HC")))
    vcovs[[i]] <- vcovHC(tmp, type = "HC")
  }
  par.est <- apply(lms, 1, mean)
  se.within <- apply(ses, 1, mean)
  se.between <- apply(lms, 1, var)
  se.est <- sqrt(se.within^2 + se.between*(1 + (1/length(midata))))
  list("terms"=names(tmp$coefficients), "beta" = par.est, "SE"=se.est, "vcovs"=vcovs,"coefs" = lms)   
}

### Load data. Data primarily from Fariss (2014), Keith et al (2009), and Keith (2012). See Appendix A for data source details and descriptions.
setwd("~/Dropbox/third/Data/PRIO/Estimation data") 
dat <- read.dta("main.dta")

attach(dat)
datfh <- na.omit(data.frame(latentmean, SL_fariss_sd, SL_fariss_cooptation, SL_fariss_structural, latentsd, lag_repression_fariss, cooptation, avg_gdp, avg_pop, dissent, SL_conflict_neigh, cold_war, lag_latentsd, y_fe1,	y_fe2,	y_fe3,	y_fe4,	y_fe5,	y_fe6,	y_fe8,	y_fe9,	y_fe10,	y_fe11,	y_fe12,	y_fe13,	y_fe14,	y_fe15,	y_fe16,	y_fe17,	y_fe18,	y_fe19,	y_fe20,	y_fe21,	y_fe22,	y_fe23,	y_fe24,	y_fe25,	y_fe26,	y_fe27,	y_fe28,	y_fe29,	y_fe30,	y_fe31,	y_fe32,	y_fe33,	y_fe34,	y_fe35,	y_fe36,	y_fe37,	y_fe38,	y_fe39,	y_fe40,	y_fe41,	y_fe42,	y_fe43,	y_fe44,	y_fe45,	y_fe46,	y_fe47,	y_fe48,	y_fe49,	y_fe50,	y_fe51,	y_fe52,	y_fe53,	y_fe54,	y_fe55,	y_fe57,	y_fe58, ccode_fe1,	ccode_fe2,	ccode_fe3,	ccode_fe4,	ccode_fe5,	ccode_fe6,	ccode_fe7,	ccode_fe8,	ccode_fe9,	ccode_fe10,	ccode_fe11,	ccode_fe12,	ccode_fe13,	ccode_fe14,	ccode_fe15,	ccode_fe16,	ccode_fe17,	ccode_fe18,	ccode_fe19,	ccode_fe20,	ccode_fe21,	ccode_fe22,	ccode_fe23,	ccode_fe24,	ccode_fe25,	ccode_fe26,	ccode_fe27,	ccode_fe28,	ccode_fe29,	ccode_fe30,	ccode_fe31,	ccode_fe32,	ccode_fe33,	ccode_fe34,	ccode_fe35,	ccode_fe36,	ccode_fe37,	ccode_fe38,	ccode_fe39,	ccode_fe40,	ccode_fe41,	ccode_fe42,	ccode_fe43,	ccode_fe44,	ccode_fe45,	ccode_fe46,	ccode_fe47,	ccode_fe48,	ccode_fe49,	ccode_fe50,	ccode_fe51,	ccode_fe52,	ccode_fe53,	ccode_fe54,	ccode_fe55,	ccode_fe56,	ccode_fe57,	ccode_fe58, ccode_fe59,	ccode_fe60,	ccode_fe61,	ccode_fe62,	ccode_fe63,	ccode_fe65,	ccode_fe66,	ccode_fe67,	ccode_fe68,	ccode_fe69,	ccode_fe70,	ccode_fe71,	ccode_fe72,	ccode_fe73,	ccode_fe74,	ccode_fe75,	ccode_fe76,	ccode_fe77,	ccode_fe78,	ccode_fe79,	ccode_fe80,	ccode_fe81,	ccode_fe82,	ccode_fe83,	ccode_fe84,	ccode_fe85,	ccode_fe86,	ccode_fe87,	ccode_fe88,	ccode_fe89,	ccode_fe90,	ccode_fe92,	ccode_fe93,	ccode_fe94,	ccode_fe95,	ccode_fe96,	ccode_fe97,	ccode_fe99,	ccode_fe100,	ccode_fe101,	ccode_fe102,	ccode_fe103,	ccode_fe104,	ccode_fe105,	ccode_fe106,	ccode_fe107,	ccode_fe108,	ccode_fe109,	ccode_fe110,	ccode_fe111,	ccode_fe112,	ccode_fe113,	ccode_fe114,	ccode_fe115))

dim(datfh)


### Setup data to run models where we account for uncertainty
set.seed(32261991)
newdata <- list()
for(i in 1:1000){
  newdata[[i]] <- datfh
  newdata[[i]]$draw <- rnorm(cbind(rep(1,nrow(datfh))), mean=datfh$latentmean, sd=datfh$latentsd)
  newdata[[i]]$draw.lag <- rnorm(cbind(rep(1,nrow(datfh))), mean=datfh$lag_repression_fariss, sd=datfh$lag_latentsd)
  newdata[[i]]$draw.lag.SL <- rnorm(cbind(rep(1,nrow(datfh))), mean=datfh$SL_fariss_cooptation, sd=datfh$SL_fariss_sd)
  
}

FML4<- "draw ~ draw.lag +  draw.lag.SL + cooptation + avg_gdp + avg_pop + dissent + SL_conflict_neigh + cold_war + lag_latentsd + y_fe1 +	y_fe2 +	y_fe3 +	y_fe4 +	y_fe5 +	y_fe6  +	y_fe8 +	y_fe9 +	y_fe10 +	y_fe11 +	y_fe12 +	y_fe13 +	y_fe14 +	y_fe15 +	y_fe16 +	y_fe17 +	y_fe18 +	y_fe19 +	y_fe20 +	y_fe21 +	y_fe22 +	y_fe23 +	y_fe24 +	y_fe25 +	y_fe26 +	y_fe27 +	y_fe28 +	y_fe29 +	y_fe30 +	y_fe31 +	y_fe32 +	y_fe33 +	y_fe34 +	y_fe35 +	y_fe36 +	y_fe37 +	y_fe38 +	y_fe39 +	y_fe40 +	y_fe41 +	y_fe42 +	y_fe43 +	y_fe44 +	y_fe45 +	y_fe46 +	y_fe47 +	y_fe48 +	y_fe49 +	y_fe50 +	y_fe51 +	y_fe52 +	y_fe53 +	y_fe54 +	y_fe55  +	y_fe57 +	y_fe58 + ccode_fe1 +	ccode_fe2 +	ccode_fe3 +	ccode_fe4 +	ccode_fe5 +	ccode_fe6 +	ccode_fe7 +	ccode_fe8 +	ccode_fe9 +	ccode_fe10 +	ccode_fe11 +	ccode_fe12 +	ccode_fe13 +	ccode_fe14 +	ccode_fe15 +	ccode_fe16 +	ccode_fe17 +	ccode_fe18 +	ccode_fe19 +	ccode_fe20 +	ccode_fe21 +	ccode_fe22 +	ccode_fe23 +	ccode_fe24 +	ccode_fe25 +	ccode_fe26 +	ccode_fe27 +	ccode_fe28 +	ccode_fe29 +	ccode_fe30 +	ccode_fe31 +	ccode_fe32 +	ccode_fe33 +	ccode_fe34 +	ccode_fe35 +	ccode_fe36 +	ccode_fe37 +	ccode_fe38 +	ccode_fe39 +	ccode_fe40 +	ccode_fe41 +	ccode_fe42 +	ccode_fe43 +	ccode_fe44 +	ccode_fe45 +	ccode_fe46 +	ccode_fe47 +	ccode_fe48 +	ccode_fe49 +	ccode_fe50 +	ccode_fe51 +	ccode_fe52 +	ccode_fe53 +	ccode_fe54 +	ccode_fe55 +	ccode_fe56 +	ccode_fe57 +	ccode_fe58 + ccode_fe59 +	ccode_fe60 +	ccode_fe61 +	ccode_fe62 +	ccode_fe63 +	ccode_fe65 +	ccode_fe66 +	ccode_fe67 +	ccode_fe68 +	ccode_fe69 +	ccode_fe70 +	ccode_fe71 +	ccode_fe72 +	ccode_fe73 +	ccode_fe74 +	ccode_fe75 +	ccode_fe76 +	ccode_fe77 +	ccode_fe78 +	ccode_fe79 +	ccode_fe80 +	ccode_fe81 +	ccode_fe82 +	ccode_fe83 +	ccode_fe84 +	ccode_fe85 +	ccode_fe86 +	ccode_fe87 +	ccode_fe88 +	ccode_fe89 +	ccode_fe90 +	ccode_fe92 +	ccode_fe93 +	ccode_fe94 +	ccode_fe95 +	ccode_fe96 +	ccode_fe97 +	ccode_fe99 +	ccode_fe100 +	ccode_fe101 +	ccode_fe102 +	ccode_fe103 +	ccode_fe104 +	ccode_fe105 +	ccode_fe106 +	ccode_fe107 +	ccode_fe108 +	ccode_fe109 +	ccode_fe110 +	ccode_fe111 +	ccode_fe112 +	ccode_fe113 +	ccode_fe114 +	ccode_fe115"

model4 <- milm(fml=FML4, midata=newdata)


### Check with uncertainty in DV and lagged DV
FML1<- "draw ~ draw.lag +  SL_fariss_cooptation + cooptation + avg_gdp + avg_pop + dissent + SL_conflict_neigh + cold_war + lag_latentsd + y_fe1 +	y_fe2 +	y_fe3 +	y_fe4 +	y_fe5 +	y_fe6  +	y_fe8 +	y_fe9 +	y_fe10 +	y_fe11 +	y_fe12 +	y_fe13 +	y_fe14 +	y_fe15 +	y_fe16 +	y_fe17 +	y_fe18 +	y_fe19 +	y_fe20 +	y_fe21 +	y_fe22 +	y_fe23 +	y_fe24 +	y_fe25 +	y_fe26 +	y_fe27 +	y_fe28 +	y_fe29 +	y_fe30 +	y_fe31 +	y_fe32 +	y_fe33 +	y_fe34 +	y_fe35 +	y_fe36 +	y_fe37 +	y_fe38 +	y_fe39 +	y_fe40 +	y_fe41 +	y_fe42 +	y_fe43 +	y_fe44 +	y_fe45 +	y_fe46 +	y_fe47 +	y_fe48 +	y_fe49 +	y_fe50 +	y_fe51 +	y_fe52 +	y_fe53 +	y_fe54 +	y_fe55  +	y_fe57 +	y_fe58 + ccode_fe1 +	ccode_fe2 +	ccode_fe3 +	ccode_fe4 +	ccode_fe5 +	ccode_fe6 +	ccode_fe7 +	ccode_fe8 +	ccode_fe9 +	ccode_fe10 +	ccode_fe11 +	ccode_fe12 +	ccode_fe13 +	ccode_fe14 +	ccode_fe15 +	ccode_fe16 +	ccode_fe17 +	ccode_fe18 +	ccode_fe19 +	ccode_fe20 +	ccode_fe21 +	ccode_fe22 +	ccode_fe23 +	ccode_fe24 +	ccode_fe25 +	ccode_fe26 +	ccode_fe27 +	ccode_fe28 +	ccode_fe29 +	ccode_fe30 +	ccode_fe31 +	ccode_fe32 +	ccode_fe33 +	ccode_fe34 +	ccode_fe35 +	ccode_fe36 +	ccode_fe37 +	ccode_fe38 +	ccode_fe39 +	ccode_fe40 +	ccode_fe41 +	ccode_fe42 +	ccode_fe43 +	ccode_fe44 +	ccode_fe45 +	ccode_fe46 +	ccode_fe47 +	ccode_fe48 +	ccode_fe49 +	ccode_fe50 +	ccode_fe51 +	ccode_fe52 +	ccode_fe53 +	ccode_fe54 +	ccode_fe55 +	ccode_fe56 +	ccode_fe57 +	ccode_fe58 + ccode_fe59 +	ccode_fe60 +	ccode_fe61 +	ccode_fe62 +	ccode_fe63 +	ccode_fe65 +	ccode_fe66 +	ccode_fe67 +	ccode_fe68 +	ccode_fe69 +	ccode_fe70 +	ccode_fe71 +	ccode_fe72 +	ccode_fe73 +	ccode_fe74 +	ccode_fe75 +	ccode_fe76 +	ccode_fe77 +	ccode_fe78 +	ccode_fe79 +	ccode_fe80 +	ccode_fe81 +	ccode_fe82 +	ccode_fe83 +	ccode_fe84 +	ccode_fe85 +	ccode_fe86 +	ccode_fe87 +	ccode_fe88 +	ccode_fe89 +	ccode_fe90 +	ccode_fe92 +	ccode_fe93 +	ccode_fe94 +	ccode_fe95 +	ccode_fe96 +	ccode_fe97 +	ccode_fe99 +	ccode_fe100 +	ccode_fe101 +	ccode_fe102 +	ccode_fe103 +	ccode_fe104 +	ccode_fe105 +	ccode_fe106 +	ccode_fe107 +	ccode_fe108 +	ccode_fe109 +	ccode_fe110 +	ccode_fe111 +	ccode_fe112 +	ccode_fe113 +	ccode_fe114 +	ccode_fe115"

FML2 <- "draw ~ draw.lag + SL_fariss_structural + cooptation + avg_gdp + avg_pop + dissent + SL_conflict_neigh + cold_war + lag_latentsd + y_fe1 +	y_fe2 +	y_fe3 +	y_fe4 +	y_fe5 +	y_fe6  +	y_fe8 +	y_fe9 +	y_fe10 +	y_fe11 +	y_fe12 +	y_fe13 +	y_fe14 +	y_fe15 +	y_fe16 +	y_fe17 +	y_fe18 +	y_fe19 +	y_fe20 +	y_fe21 +	y_fe22 +	y_fe23 +	y_fe24 +	y_fe25 +	y_fe26 +	y_fe27 +	y_fe28 +	y_fe29 +	y_fe30 +	y_fe31 +	y_fe32 +	y_fe33 +	y_fe34 +	y_fe35 +	y_fe36 +	y_fe37 +	y_fe38 +	y_fe39 +	y_fe40 +	y_fe41 +	y_fe42 +	y_fe43 +	y_fe44 +	y_fe45 +	y_fe46 +	y_fe47 +	y_fe48 +	y_fe49 +	y_fe50 +	y_fe51 +	y_fe52 +	y_fe53 +	y_fe54 +	y_fe55  +	y_fe57 +	y_fe58 + ccode_fe1 +	ccode_fe2 +	ccode_fe3 +	ccode_fe4 +	ccode_fe5 +	ccode_fe6 +	ccode_fe7 +	ccode_fe8 +	ccode_fe9 +	ccode_fe10 +	ccode_fe11 +	ccode_fe12 +	ccode_fe13 +	ccode_fe14 +	ccode_fe15 +	ccode_fe16 +	ccode_fe17 +	ccode_fe18 +	ccode_fe19 +	ccode_fe20 +	ccode_fe21 +	ccode_fe22 +	ccode_fe23 +	ccode_fe24 +	ccode_fe25 +	ccode_fe26 +	ccode_fe27 +	ccode_fe28 +	ccode_fe29 +	ccode_fe30 +	ccode_fe31 +	ccode_fe32 +	ccode_fe33 +	ccode_fe34 +	ccode_fe35 +	ccode_fe36 +	ccode_fe37 +	ccode_fe38 +	ccode_fe39 +	ccode_fe40 +	ccode_fe41 +	ccode_fe42 +	ccode_fe43 +	ccode_fe44 +	ccode_fe45 +	ccode_fe46 +	ccode_fe47 +	ccode_fe48 +	ccode_fe49 +	ccode_fe50 +	ccode_fe51 +	ccode_fe52 +	ccode_fe53 +	ccode_fe54 +	ccode_fe55 +	ccode_fe56 +	ccode_fe57 +	ccode_fe58 + ccode_fe59 +	ccode_fe60 +	ccode_fe61 +	ccode_fe62 +	ccode_fe63 +	ccode_fe65 +	ccode_fe66 +	ccode_fe67 +	ccode_fe68 +	ccode_fe69 +	ccode_fe70 +	ccode_fe71 +	ccode_fe72 +	ccode_fe73 +	ccode_fe74 +	ccode_fe75 +	ccode_fe76 +	ccode_fe77 +	ccode_fe78 +	ccode_fe79 +	ccode_fe80 +	ccode_fe81 +	ccode_fe82 +	ccode_fe83 +	ccode_fe84 +	ccode_fe85 +	ccode_fe86 +	ccode_fe87 +	ccode_fe88 +	ccode_fe89 +	ccode_fe90 +	ccode_fe92 +	ccode_fe93 +	ccode_fe94 +	ccode_fe95 +	ccode_fe96 +	ccode_fe97 +	ccode_fe99 +	ccode_fe100 +	ccode_fe101 +	ccode_fe102 +	ccode_fe103 +	ccode_fe104 +	ccode_fe105 +	ccode_fe106 +	ccode_fe107 +	ccode_fe108 +	ccode_fe109 +	ccode_fe110 +	ccode_fe111 +	ccode_fe112 +	ccode_fe113 +	ccode_fe114 +	ccode_fe115"

FML3 <- "draw ~ draw.lag +  SL_fariss_cooptation + SL_fariss_structural + cooptation + avg_gdp + avg_pop + dissent + SL_conflict_neigh + cold_war + lag_latentsd + y_fe1 +	y_fe2 +	y_fe3 +	y_fe4 +	y_fe5 +	y_fe6  +	y_fe8 +	y_fe9 +	y_fe10 +	y_fe11 +	y_fe12 +	y_fe13 +	y_fe14 +	y_fe15 +	y_fe16 +	y_fe17 +	y_fe18 +	y_fe19 +	y_fe20 +	y_fe21 +	y_fe22 +	y_fe23 +	y_fe24 +	y_fe25 +	y_fe26 +	y_fe27 +	y_fe28 +	y_fe29 +	y_fe30 +	y_fe31 +	y_fe32 +	y_fe33 +	y_fe34 +	y_fe35 +	y_fe36 +	y_fe37 +	y_fe38 +	y_fe39 +	y_fe40 +	y_fe41 +	y_fe42 +	y_fe43 +	y_fe44 +	y_fe45 +	y_fe46 +	y_fe47 +	y_fe48 +	y_fe49 +	y_fe50 +	y_fe51 +	y_fe52 +	y_fe53 +	y_fe54 +	y_fe55  +	y_fe57 +	y_fe58 + ccode_fe1 +	ccode_fe2 +	ccode_fe3 +	ccode_fe4 +	ccode_fe5 +	ccode_fe6 +	ccode_fe7 +	ccode_fe8 +	ccode_fe9 +	ccode_fe10 +	ccode_fe11 +	ccode_fe12 +	ccode_fe13 +	ccode_fe14 +	ccode_fe15 +	ccode_fe16 +	ccode_fe17 +	ccode_fe18 +	ccode_fe19 +	ccode_fe20 +	ccode_fe21 +	ccode_fe22 +	ccode_fe23 +	ccode_fe24 +	ccode_fe25 +	ccode_fe26 +	ccode_fe27 +	ccode_fe28 +	ccode_fe29 +	ccode_fe30 +	ccode_fe31 +	ccode_fe32 +	ccode_fe33 +	ccode_fe34 +	ccode_fe35 +	ccode_fe36 +	ccode_fe37 +	ccode_fe38 +	ccode_fe39 +	ccode_fe40 +	ccode_fe41 +	ccode_fe42 +	ccode_fe43 +	ccode_fe44 +	ccode_fe45 +	ccode_fe46 +	ccode_fe47 +	ccode_fe48 +	ccode_fe49 +	ccode_fe50 +	ccode_fe51 +	ccode_fe52 +	ccode_fe53 +	ccode_fe54 +	ccode_fe55 +	ccode_fe56 +	ccode_fe57 +	ccode_fe58 + ccode_fe59 +	ccode_fe60 +	ccode_fe61 +	ccode_fe62 +	ccode_fe63 +	ccode_fe65 +	ccode_fe66 +	ccode_fe67 +	ccode_fe68 +	ccode_fe69 +	ccode_fe70 +	ccode_fe71 +	ccode_fe72 +	ccode_fe73 +	ccode_fe74 +	ccode_fe75 +	ccode_fe76 +	ccode_fe77 +	ccode_fe78 +	ccode_fe79 +	ccode_fe80 +	ccode_fe81 +	ccode_fe82 +	ccode_fe83 +	ccode_fe84 +	ccode_fe85 +	ccode_fe86 +	ccode_fe87 +	ccode_fe88 +	ccode_fe89 +	ccode_fe90 +	ccode_fe92 +	ccode_fe93 +	ccode_fe94 +	ccode_fe95 +	ccode_fe96 +	ccode_fe97 +	ccode_fe99 +	ccode_fe100 +	ccode_fe101 +	ccode_fe102 +	ccode_fe103 +	ccode_fe104 +	ccode_fe105 +	ccode_fe106 +	ccode_fe107 +	ccode_fe108 +	ccode_fe109 +	ccode_fe110 +	ccode_fe111 +	ccode_fe112 +	ccode_fe113 +	ccode_fe114 +	ccode_fe115"

model1 <- milm(fml=FML1, midata=newdata)
model2 <- milm(fml=FML2, midata=newdata)
model3 <- milm(fml=FML3, midata=newdata)



df <- 3685
tstats<-data.frame(model1$terms,model1$beta,model1$SE,model1$beta/model1$SE,2*pt(-abs(model1$beta/model1$SE),df=df))
colnames(tstats) <- c("Variable","Est. Coef.","SE","t-stat","p")
tstats


df <- 3685
tstats<-data.frame(model2$terms,model2$beta,model2$SE,model2$beta/model2$SE,2*pt(-abs(model2$beta/model2$SE),df=df))
colnames(tstats) <- c("Variable","Est. Coef.","SE","t-stat","p")
tstats

df <- 3684
tstats<-data.frame(model3$terms,model3$beta,model3$SE,model3$beta/model3$SE,2*pt(-abs(model3$beta/model3$SE),df=df))
colnames(tstats) <- c("Variable","Est. Coef.","SE","t-stat","p")
tstats

df <- 3685
tstats<-data.frame(model4$terms,model4$beta,model4$SE,model4$beta/model4$SE,2*pt(-abs(model4$beta/model4$SE),df=df))
colnames(tstats) <- c("Variable","Est. Coef.","SE","t-stat","p")
tstats
